/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.ow2.petals.admin.api.ArtifactAdministration;
import org.ow2.petals.admin.api.artifact.Artifact;
import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycle;
import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycleFactory;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.ArtifactNotFoundException;
import org.ow2.petals.admin.api.exception.ArtifactTypeIsNeededException;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public class ArtifactAdministrationMock extends ArtifactAdministration {

    public ArtifactAdministrationMock(final ArtifactLifecycleFactory artifactLifecycle) {
        super(artifactLifecycle);
    }

    @Override
    public void stopAndUndeployAllArtifacts() throws ArtifactAdministrationException {

        Artifact[] artifacts = RegistryMock.getInstance().list();
        for (Artifact a : artifacts) {
            ArtifactLifecycle aLifecycle = this.artifactLifecycleFactory.createLifecycle(a);
            aLifecycle.stop();
            aLifecycle.undeploy();
        }
    }

    @Override
    public List<Artifact> listArtifacts() throws ArtifactAdministrationException {
        return Arrays.asList(RegistryMock.getInstance().list());
    }

    @Override
    public Artifact getArtifact(String type, String name) throws ArtifactAdministrationException {
        assert name != null;

        Artifact[] artifacts = RegistryMock.getInstance().list();
        final List<Artifact> artifactsMatchingName = new ArrayList<Artifact>();
        if (type != null) {
            for (Artifact artifact : artifacts) {
                if (artifact.getType().equals(type) && artifact.getName().equals(name)) {
                    artifactsMatchingName.add(artifact);
                }
            }
        } else {
            for (Artifact artifact : artifacts) {
                if (artifact.getName().equals(name)) {
                    artifactsMatchingName.add(artifact);
                }
            }
        }
        if (artifactsMatchingName.size() == 0) {
            throw new ArtifactNotFoundException(type, name);
        } else if (artifactsMatchingName.size() > 1) {
            throw new ArtifactTypeIsNeededException(name);
        } else {
            return artifactsMatchingName.get(0);
        }
    }

}
