/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin;

import java.net.URL;

import org.ow2.petals.admin.api.artifact.ArtifactState.State;
import org.ow2.petals.admin.api.artifact.Component;
import org.ow2.petals.admin.api.artifact.lifecycle.ComponentLifecycle;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public class ComponentLifecycleMock implements ComponentLifecycle {

    private final Component component;

    public ComponentLifecycleMock(Component c) {
        this.component = c;
    }

    @Override
    public Component getComponent() {
        return this.component;
    }

    @Override
    public void deploy(URL artifactUrl) throws ArtifactAdministrationException {
        RegistryMock.getInstance().add(getComponent());
    }

    @Override
    public void start() throws ArtifactAdministrationException {
        Component found = (Component) RegistryMock.getInstance().get(getComponent());
        if (found == null)
            throw new ArtifactAdministrationException(
                    "Artifact not found in registry. Can not update state");
        found.setState(State.STARTED);

    }

    @Override
    public void stop() throws ArtifactAdministrationException {
        Component found = (Component) RegistryMock.getInstance().get(getComponent());
        if (found == null)
            throw new ArtifactAdministrationException(
                    "Artifact not found in registry. Can not update state");
        found.setState(State.STOPPED);
    }

    @Override
    public void undeploy() throws ArtifactAdministrationException {
        RegistryMock.getInstance().remove(getComponent());
    }

    @Override
    public void updateState() throws ArtifactAdministrationException {
        Component found = (Component) RegistryMock.getInstance().get(getComponent());
        if (found == null)
            throw new ArtifactAdministrationException(
                    "Artifact not found in registry. Can not update state");
        getComponent().setState(found.getState());
    }

}
